#
# spec file for package apache2-mod_auth_mellon
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define upstream_name mod_auth_mellon
Name:           apache2-mod_auth_mellon
Version:        0.17.0
Release:        2.10
Summary:        A SAML 2.0 authentication module for the Apache Server
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Web/Servers
URL:            https://github.com/latchset/%{upstream_name}
Source0:        https://github.com/latchset/%{upstream_name}/releases/download/v%{version}/%{upstream_name}-%{version}.tar.gz
Source1:        %{upstream_name}.conf
Source2:        %{name}.conf
Source3:        README.diagnostics
Patch0:         mod_auth_mellon-0.16.0-env-script-interpreter.patch
BuildRequires:  apache-rpm-macros
BuildRequires:  apache2-devel
BuildRequires:  curl-devel
BuildRequires:  gcc
BuildRequires:  glib2-devel
BuildRequires:  openssl-devel
BuildRequires:  pkgconfig
BuildRequires:  xmlsec1-devel
BuildRequires:  pkgconfig(lasso) >= 2.5.1
BuildRequires:  rubygem(asciidoctor)
Requires:       %{apache_mmn}
Requires:       %{apache_suse_maintenance_mmn}
Requires:       liblasso3 >= 2.5.1

%description
The mod_auth_mellon module is an authentication service that implements the
SAML 2.0 federation protocol. It grants access based on the attributes
received in assertions generated by a IdP server.

%package doc
Summary:        Documentation for mod_auth_mellon module
Group:          Productivity/Networking/Web/Servers
Requires:       %{name} = %{version}

%description doc
This package contains a documentation for mod_auth_mellon module.

%package diagnostics
Summary:        Build of mod_auth_mellon with diagnostic logging
Group:          Productivity/Networking/Web/Servers
Requires:       %{name} = %{version}-%{release}

%description diagnostics
Build of mod_auth_mellon with diagnostic logging. See README.diagnostics
in the doc directory for instructions on using the diagnostics build.

%prep
%autosetup -n %{upstream_name}-%{version}

%build
export APXS=%{_httpd_apxs}
%configure --enable-diagnostics
%make_build clean
%make_build
cp .libs/%{upstream_name}.so %{upstream_name}-diagnostics.so

%configure
%make_build clean
%make_build
pushd doc/user_guide
asciidoctor -a data-uri mellon_user_guide.adoc
popd

%install
# install module
mkdir -p %{buildroot}/%{apache_libexecdir}
install -m 755 .libs/%{upstream_name}.so %{buildroot}%{apache_libexecdir}
install -m 755 %{upstream_name}-diagnostics.so %{buildroot}%{apache_libexecdir}

# install module configuration
mkdir -p %{buildroot}%{_sysconfdir}/apache2/conf.d
install -m 644 %{SOURCE1} %{buildroot}%{_sysconfdir}/apache2/conf.d

install -d -m 0755 %{buildroot}%{_tmpfilesdir}
install -m 0644 %{SOURCE2} %{buildroot}%{_tmpfilesdir}/%{name}.conf

# install script to generate metadata
mkdir -p %{buildroot}/%{_libexecdir}/%{name}
install -m 755 mellon_create_metadata.sh %{buildroot}/%{_libexecdir}/%{name}

# install user guide
mkdir -p %{buildroot}/%{_docdir}
cp -r doc/user_guide %{buildroot}/%{_docdir}

# install diagnostics README
install -m 0644  %{SOURCE3} %{buildroot}/%{_docdir}

%post
%tmpfiles_create %{_tmpfilesdir}/%{name}.conf

%files diagnostics
%{apache_libexecdir}/%{upstream_name}-diagnostics.so

%files
%license COPYING
%doc README.md NEWS ECP.rst
%config(noreplace) %{_sysconfdir}/apache2/conf.d/%{upstream_name}.conf
%{apache_libexecdir}/%{upstream_name}.so
%{_tmpfilesdir}/%{name}.conf
%{_libexecdir}/%{name}
%ghost /run/mod_auth_mellon

%files doc
%doc %{_docdir}/README.diagnostics
%doc %{_docdir}/user_guide

%changelog
* Thu May  5 2022 Archie Cobbs <archie.cobbs@gmail.com>
- Wrap default config in <IfModule> to avoid reload error
* Thu Sep 10 2020 Kristyna Streitova <kstreitova@suse.com>
- Update to 0.17.0
  * New option MellonSendExpectHeader (default On) which allows to
    disable sending the Expect header in the HTTP-Artifact binding to
    improve performance when the remote party does not support this
    header.
  * Set SameSite attribute to None on on the cookietest cookie.
  * Bump default generated keysize to 3072 bits in
    mellon_create_metadata
  * Validate if the assertion ID has not been used earlier before
    creating a new session.
  * Release session cache after calling invalidate endpoint.
  * In MellonCond directives, fix a bug that setting the NC option
    would also activate substring match and that REG would activate
    REF.
  * Fix MellonCond substring match to actually match the substring on
    the attribute value
* Thu Jun  4 2020 Kristyna Streitova <kstreitova@suse.com>
- update mod_auth_mellon-0.16.0-env-script-interpreter.patch
  use /bin/bash instead of /usr/bin/bash
* Mon May 11 2020 Kristyna Streitova <kstreitova@suse.com>
- replace version_path with the fixed value
* Tue Apr 28 2020 Kristyna Streitova <kstreitova@suse.com>
- initial packaging
